@@ -2,14 +2,11 @@ from dataclasses import dataclass
 from typing import *
 
 from .typings import *
-from ..typings import ModelInstance
 
 __all__ = [
     "ApplyHandler"
 ]
 
-from ..utils import iteration
-
 
 @dataclass
 class ApplyHandler:
